scandaloriantypes

package module
v0.0.0-...-1f5cac7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 22, 2022 License: Apache-2.0 Imports: 0 Imported by: 4

README

scandalorian-types

Type definitions for Scandalorian API surface

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetApplicationStream

func GetApplicationStream() string

func GetDiscoveryStream

func GetDiscoveryStream() string

func GetHostInfoStream

func GetHostInfoStream() string

func GetReverseDNSStream

func GetReverseDNSStream() string

Types

type ApplicationScan

type ApplicationScan struct {
	ScanMetaData
	Run         bool      `json:"run"`
	Flags       BaseFlags `json:"flags"`
	UDPFlags    UDPFlags  `json:"udp_flags,omitempty"`
	HttpOptions *Http     `json:"http_options,omitempty"`
}

Top Level Object to define application level scanning

func (*ApplicationScan) GetStream

func (as *ApplicationScan) GetStream() string

func (*ApplicationScan) SetDefaults

func (as *ApplicationScan) SetDefaults(scan *ScanMetaData)

type Bacnet

type Bacnet struct {
}
type Banner struct {
}

type BaseFlags

type BaseFlags struct {
	Port           uint   `json:"port"`
	Name           string `json:"name"`
	Timeout        int    `json:"timeout"`
	Trigger        string `json:"trigger"`
	BytesReadLimit int    `json:"byte_read_limit"`
}

BaseFlags contains the options that every flags type must embed

type CustomMeta

type CustomMeta map[string]string

type Dnp3

type Dnp3 struct {
}

type Fox

type Fox struct {
}

type HostEnrichmentScan

type HostEnrichmentScan struct {
	ScanMetaData
	Domain     string     `json:"domain"`
	CustomMeta CustomMeta `json:"custom_meta,omitempty"`
}

Top level struct to define host information discovery

func (*HostEnrichmentScan) GetStream

func (he *HostEnrichmentScan) GetStream() string

func (*HostEnrichmentScan) SetDefaults

func (he *HostEnrichmentScan) SetDefaults(scan *ScanMetaData)

type Http

type Http struct {
}

type Imap

type Imap struct {
}

type Ipp

type Ipp struct {
}

type Jarm

type Jarm struct {
}

type MSSQL

type MSSQL struct {
}

type Modbus

type Modbus struct {
}

type Mongo

type Mongo struct {
}

type Ntp

type Ntp struct {
}

type Oracle

type Oracle struct {
}

type Pop3

type Pop3 struct {
}

type PortScan

type PortScan struct {
	ScanMetaData
	Run                    bool     `json:"run"`
	PPS                    int      `json:"pps,omitempty"` // Set rate limiter value
	Ports                  []int    `json:"ports,omitempty"`
	TopTen                 bool     `json:"top_ten,omitempty"`
	TopHundred             bool     `json:"top_hundred,omitempty"`
	TopThousand            bool     `json:"top_thousand,omitempty"`
	HostScanTimeoutSeconds int      `json:"host_scan_timeout_seconds"`
	Errors                 []string `json:"errors,omitempty"`
}

Top level object to define a port scan

func (*PortScan) GetStream

func (ps *PortScan) GetStream() string

func (*PortScan) SetDefaults

func (ps *PortScan) SetDefaults(scan *ScanMetaData)

type Postgres

type Postgres struct {
}

type Redis

type Redis struct {
}

type SMB

type SMB struct {
}

type SMTP

type SMTP struct {
}

type SSH

type SSH struct {
}

type Scan

type Scan interface {
	SetDefaults(scan *ScanMetaData)
	GetStream() string
}

type ScanMetaData

type ScanMetaData struct {
	IP        string `json:"ip"`
	Requestor string `json:"requestor"`
	RequestID string `json:"request_id"`
	Stream    string `json:"-"`
}

Scan structure to send to message queue for scanning

type ScanRequest

type ScanRequest struct {
	Host            string           `json:"host"`
	Company         string           `json:"company"`
	FQDN            string           `json:"fqdn,omitempty"`
	PortScan        *PortScan        `json:"port_scan,omitempty"`
	ApplicationScan *ApplicationScan `json:"application_scan,omitempty"`
	CustomMeta      CustomMeta       `json:"custom_meta,omitempty"`
}

ScanRequest object instructing system on how to scan.

type Siemens

type Siemens struct {
}

type TLS

type TLS struct {
}

type Telnet

type Telnet struct {
}

type UDPFlags

type UDPFlags struct {
	LocalPort    uint   `json:"local_port"`
	LocalAddress string `json:"local_address"`
}

Jump to