Documentation
¶
Index ¶
- func GetApplicationStream() string
- func GetDiscoveryStream() string
- func GetHostInfoStream() string
- func GetReverseDNSStream() string
- type ApplicationScan
- type Bacnet
- type Banner
- type BaseFlags
- type CustomMeta
- type Dnp3
- type Fox
- type HostEnrichmentScan
- type Http
- type Imap
- type Ipp
- type Jarm
- type MSSQL
- type Modbus
- type Mongo
- type Ntp
- type Oracle
- type Pop3
- type PortScan
- type Postgres
- type Redis
- type SMB
- type SMTP
- type SSH
- type Scan
- type ScanMetaData
- type ScanRequest
- type Siemens
- type TLS
- type Telnet
- type UDPFlags
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetApplicationStream ¶
func GetApplicationStream() string
func GetDiscoveryStream ¶
func GetDiscoveryStream() string
func GetHostInfoStream ¶
func GetHostInfoStream() string
func GetReverseDNSStream ¶
func GetReverseDNSStream() string
Types ¶
type ApplicationScan ¶
type ApplicationScan struct {
ScanMetaData
Run bool `json:"run"`
Flags BaseFlags `json:"flags"`
UDPFlags UDPFlags `json:"udp_flags,omitempty"`
HttpOptions *Http `json:"http_options,omitempty"`
}
Top Level Object to define application level scanning
func (*ApplicationScan) GetStream ¶
func (as *ApplicationScan) GetStream() string
func (*ApplicationScan) SetDefaults ¶
func (as *ApplicationScan) SetDefaults(scan *ScanMetaData)
type BaseFlags ¶
type BaseFlags struct {
Port uint `json:"port"`
Name string `json:"name"`
Timeout int `json:"timeout"`
Trigger string `json:"trigger"`
BytesReadLimit int `json:"byte_read_limit"`
}
BaseFlags contains the options that every flags type must embed
type CustomMeta ¶
type HostEnrichmentScan ¶
type HostEnrichmentScan struct {
ScanMetaData
Domain string `json:"domain"`
CustomMeta CustomMeta `json:"custom_meta,omitempty"`
}
Top level struct to define host information discovery
func (*HostEnrichmentScan) GetStream ¶
func (he *HostEnrichmentScan) GetStream() string
func (*HostEnrichmentScan) SetDefaults ¶
func (he *HostEnrichmentScan) SetDefaults(scan *ScanMetaData)
type PortScan ¶
type PortScan struct {
ScanMetaData
Run bool `json:"run"`
PPS int `json:"pps,omitempty"` // Set rate limiter value
Ports []int `json:"ports,omitempty"`
TopTen bool `json:"top_ten,omitempty"`
TopHundred bool `json:"top_hundred,omitempty"`
TopThousand bool `json:"top_thousand,omitempty"`
HostScanTimeoutSeconds int `json:"host_scan_timeout_seconds"`
Errors []string `json:"errors,omitempty"`
}
Top level object to define a port scan
func (*PortScan) SetDefaults ¶
func (ps *PortScan) SetDefaults(scan *ScanMetaData)
type Scan ¶
type Scan interface {
SetDefaults(scan *ScanMetaData)
GetStream() string
}
type ScanMetaData ¶
type ScanMetaData struct {
IP string `json:"ip"`
Requestor string `json:"requestor"`
RequestID string `json:"request_id"`
Stream string `json:"-"`
}
Scan structure to send to message queue for scanning
type ScanRequest ¶
type ScanRequest struct {
Host string `json:"host"`
Company string `json:"company"`
FQDN string `json:"fqdn,omitempty"`
PortScan *PortScan `json:"port_scan,omitempty"`
ApplicationScan *ApplicationScan `json:"application_scan,omitempty"`
CustomMeta CustomMeta `json:"custom_meta,omitempty"`
}
ScanRequest object instructing system on how to scan.
Click to show internal directories.
Click to hide internal directories.